@@ -9,7 +9,6 @@
 (custom-add-loads 'menu '("recent-files"))
 (custom-add-loads 'minibuffer '("detached-minibuf" "icomplete" "savehist"))
 (custom-add-loads 'environment '("popper"))
-(custom-add-loads 'mic-paren '("mic-paren"))
 (custom-add-loads 'man '("man"))
 (custom-add-loads 'completion '("completion"))
 (custom-add-loads 'tools '("func-menu" "lazy-shot"))
@@ -23,11 +22,12 @@
 (custom-add-loads 'paren-matching '("paren"))
 (custom-add-loads 'avoid '("avoid"))
 (custom-add-loads 'help '("man"))
+(custom-add-loads 'winring '("winring"))
 (custom-add-loads 'data '("saveplace"))
 (custom-add-loads 'backup '("backup-dir"))
 (custom-add-loads 'id-select '("id-select"))
 (custom-add-loads 'outl-mouse '("outl-mouse"))
-(custom-add-loads 'frames '("balloon-help" "desktop" "detached-minibuf" "rsz-minibuf"))
+(custom-add-loads 'frames '("balloon-help" "desktop" "detached-minibuf" "rsz-minibuf" "winring"))
 (custom-add-loads 'bookmarks '("bookmark"))
 (custom-add-loads 'desktop '("desktop"))
 (custom-add-loads 'abbrev '("dabbrev"))
@@ -40,6 +40,7 @@
 (custom-add-loads 'fast-lock '("fast-lock"))
 (custom-add-loads 'where-was-i '("where-was-i-db"))
 (custom-add-loads 'popper '("popper"))
+(custom-add-loads 'manual '("man"))
 (custom-add-loads 'tempo '("tempo"))
 (custom-add-loads 'detached-minibuf '("detached-minibuf"))
 (custom-add-loads 'resize-minibuffer '("rsz-minibuf"))
@@ -47,8 +48,8 @@
 (custom-add-loads 'faces '("fast-lock" "lazy-shot"))
 (custom-add-loads 'pages '("page-ext"))
 (custom-add-loads 'savehist '("savehist"))
-(custom-add-loads 'editing '("bookmark"))
-(custom-add-loads 'matching '("paren" "completion" "id-select" "mic-paren"))
+(custom-add-loads 'editing '("bookmark" "permanent-buffers"))
+(custom-add-loads 'matching '("paren" "completion" "id-select"))
 (custom-add-loads 'c '("func-menu"))
 
 ;;; custom-load.el ends here
